--[[--------------------------------------------------------------
Enchant Vellum
by Sunsequent

A button in enchanting window to automatically cast enchant on 
vellum in the bag, if present.

Version 1.4.2
Release Date 06.11.2022
--------------------------------------------------------------]]--

---- Version 1.4.2
-- Potential fix for "addon action blocked" error

---- Version 1.4.1
-- Bugfix

---- Version 1.4.0
-- Updated for Dragonflight

-- Localization
local locale;
local enchantingName;
local buttonText;
local vellumCountText;
local buttonWidth;
local buttonLocX;

_G["BINDING_HEADER_ENCHANTVELLUM"] = "Enchant Vellum";

local function SetLocalization()
	-- Localization:
	-- enUS Vellums in backpack			Enchant Vellum
	-- deDE Pergament im Rucksack		Verzaubern Pergament
	-- esES Vitelas en la mochila		Encantar Vitela
	-- esMX Vitelas en la mochila		Encantar Vitela
	-- frFR Vélins dans le sac à dos	Enchantement Vélin
	-- itIT Velli nello zaino			Incantamento Vello
	-- koKR 배낭에있는 피지				마법부여 피지
	-- ptBR Velinos na mochila			Encantamento Velino
	-- ruRU Cвитков в рюкзаке			Чар Cвитeк
	-- zhCN 背包羊皮纸					附魔羊皮纸
	-- zhTW 背包羊皮纸					附魔羊皮纸
	
	locale = GetLocale();
	
	enchantingName = GetSpellInfo(7412);
	
	buttonWidth = 125;
	buttonLocX = -18;
	
	if locale == "enUS" then
		vellumCountText = "Vellums in backpack";
		buttonText = "Enchant Vellum";		
	elseif locale == "deDE" then
		vellumCountText = "Pergament im Rucksack";
		buttonText = "Verzaubern Pergament";
		
		buttonWidth = buttonWidth + 25;
		buttonLocX = buttonLocX - 25;
	elseif locale == "esES" or locale == "esMX" then
		vellumCountText = "Vitelas en la mochila";
		buttonText = "Encantar Vitela";
	elseif locale == "frFR" then
		vellumCountText = "Vélins dans le sac à dos";
		buttonText = "Enchantement Vélin";
		
		buttonWidth = buttonWidth + 25;
		buttonLocX = buttonLocX - 25;
	elseif locale == "itIT" then
		vellumCountText = "Velli nello zaino";
		buttonText = "Incantamento Vello";
		
		buttonWidth = buttonWidth + 25;
		buttonLocX = buttonLocX - 25;
	elseif locale == "koKR" then
		vellumCountText = "배낭에있는 피지";
		buttonText = "마법부여 피지";
	elseif locale == "ptBR" then
		vellumCountText = "Velinos na mochila";
		buttonText = "Encantamento Velino";
		
		buttonWidth = buttonWidth + 25;
		buttonLocX = buttonLocX - 25;
	elseif locale == "ruRU" then
		vellumCountText = "Cвитков в рюкзаке";
		buttonText = "Чар Cвитeк";
		
		buttonWidth = buttonWidth - 25;
		buttonLocX = buttonLocX + 25;
	elseif locale == "zhCN" or locale == "zhTW" then
		vellumCountText = "背包羊皮纸";
		buttonText = "附魔羊皮纸";
		
		buttonWidth = buttonWidth - 25;
		buttonLocX = buttonLocX + 25;
	end
	
	_G["BINDING_NAME_CLICK EnchantVellumButton:LeftButton"] = buttonText.." Button";
end

local button = CreateFrame("Button", "EnchantVellumButton", UIParent, "SecureActionButtonTemplate");
local frameVellumCount = CreateFrame("Frame", "EnchantingVellumCount");

local function CreateEVFrames()
	frameVellumCount:SetParent(ProfessionsFrame.CraftingPage.CreateButton);
	frameVellumCount:SetSize(250,25);
	frameVellumCount:SetPoint("TOPLEFT", ProfessionsFrame.CraftingPage.CreateButton, "TOPLEFT", -199, 25);
	frameVellumCount.text = frameVellumCount.text or frameVellumCount:CreateFontString(nil, "OVERLAY", "GameFontNormal"); --GameFontNormal GameFontNormalLarge GameFontHighlight
	frameVellumCount.text:SetAllPoints(true);
	frameVellumCount.text:SetJustifyH("LEFT");
	frameVellumCount.text:SetJustifyV("TOP");
	frameVellumCount.text:SetTextColor(1,0.8046,0,1); --1,0.8046,0,1  1,0.84,0,1
	
	button:SetParent(ProfessionsFrame.CraftingPage.CreateButton);
	button:SetSize(buttonWidth, 22); --Width, Height
	button:SetPoint("TOPLEFT", ProfessionsFrame.CraftingPage.CreateButton, "TOPLEFT", buttonLocX, 30);
	button:SetText(buttonText);
	button:SetNormalFontObject("GameFontNormal");
	button:SetDisabledFontObject("GameFontDisable")
	button:SetAttribute("type1", "macro");
	button:SetAttribute("macrotext1", "");
	
	local ntex = button:CreateTexture();
	ntex:SetTexture("Interface/Buttons/UI-Panel-Button-Up");
	ntex:SetTexCoord(0, 0.625, 0, 0.6875);
	ntex:SetAllPoints();
	button:SetNormalTexture(ntex);

	local htex = button:CreateTexture();
	htex:SetTexture("Interface/Buttons/UI-Panel-Button-Highlight");
	htex:SetTexCoord(0, 0.625, 0, 0.6875);
	htex:SetAllPoints();
	button:SetHighlightTexture(htex);

	local ptex = button:CreateTexture();
	ptex:SetTexture("Interface/Buttons/UI-Panel-Button-Down");
	ptex:SetTexCoord(0, 0.625, 0, 0.6875);
	ptex:SetAllPoints();
	button:SetPushedTexture(ptex);
	
	local dtex = button:CreateTexture();
	dtex:SetTexture("Interface/Buttons/UI-Panel-Button-Disabled");
	dtex:SetTexCoord(0, 0.625, 0, 0.6875);
	dtex:SetAllPoints();
	button:SetDisabledTexture(dtex);
end

local function HideEVFrames()
	frameVellumCount:Hide();
	button:Hide();
	button:SetAttribute("macrotext1", "");
end

local function UpdateEVFrames()
	local openedProfession = ProfessionsFrameTitleText:GetText();		
	
	if openedProfession and openedProfession:find(enchantingName) then
		local recipeID = ProfessionsFrame.CraftingPage.SchematicForm.currentRecipeInfo.recipeID;
		
		if recipeID then
			local recipeLink = C_TradeSkillUI.GetRecipeItemLink(recipeID);
			
			if recipeLink then
				if not select(3, strfind(recipeLink, "item:(%d+)")) then
					local recipeDescription = C_TradeSkillUI.GetRecipeDescription(recipeID, {});

					--ITEM_SOULBOUND -- "Soulbound" localization variable
					if not string.find(string.lower(recipeDescription), string.lower(ITEM_SOULBOUND)) then
						local numberOfVellums = GetItemCount(38682, true, false, true);
						
						if numberOfVellums and numberOfVellums > 0 then
							local vellumName = GetItemInfo(38682);

							if vellumName then
								frameVellumCount.text:SetText(vellumName..": "..numberOfVellums);
								frameVellumCount:Show();
								button:SetAttribute("macrotext1", "/run C_TradeSkillUI.CraftRecipe("..recipeID..");\n/click StaticPopup1Button1;\n/use "..vellumName..";"); --\n/click StaticPopup1Button1;
								button:Show();
								
								if C_TradeSkillUI.GetCraftableCount(recipeID) > 0 then
									button:Enable();
								else 
									button:Disable();
								end

								return;
							end						
						end						
					end
				end
			end
		end
	end

	HideEVFrames();
end

local f = CreateFrame("Frame", "EnchantVellumEventFrame")
f:SetScript("OnEvent", function(self, event, ...)
	if event == "ADDON_LOADED" then
		loadedAddon = select(1, ...);
		
		if loadedAddon == "EnchantVellum" then
			SetLocalization();	
			CreateEVFrames();
		end
	elseif event == "PLAYER_REGEN_DISABLED" then
		frameVellumCount:Hide();
		button:Hide();
	elseif event == "PLAYER_REGEN_ENABLED" then
		if ProfessionsFrame:IsShown() then
			UpdateEVFrames();
		else 
			HideEVFrames();
		end
	end
end)
f:RegisterEvent("ADDON_LOADED");
f:RegisterEvent("PLAYER_REGEN_DISABLED");
f:RegisterEvent("PLAYER_REGEN_ENABLED");

frameVellumCount:SetScript("OnEvent", function(self, event, ...)
	if not InCombatLockdown() then
		if ProfessionsFrame:IsShown() then
			UpdateEVFrames();
		else 
			HideEVFrames();
		end
	end
end)
frameVellumCount:RegisterEvent("BAG_UPDATE");
frameVellumCount:RegisterEvent("TRADE_SKILL_SHOW");
frameVellumCount:RegisterEvent("TRADE_SKILL_LIST_UPDATE");
frameVellumCount:RegisterEvent("TRADE_SKILL_DETAILS_UPDATE");
frameVellumCount:RegisterEvent("SPELL_DATA_LOAD_RESULT");
frameVellumCount:RegisterEvent("UPDATE_TRADESKILL_RECAST");
